# Generated by Django 5.0.6 on 2024-08-30 01:54

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("slurpit_netbox", "0019_alter_slurpitvlan_name"),
    ]

    operations = [
        migrations.AlterField(
            model_name="slurpitinitipaddress",
            name="ignore_description",
            field=models.BooleanField(default=False, null=True),
        ),
        migrations.AlterField(
            model_name="slurpitinitipaddress",
            name="ignore_role",
            field=models.BooleanField(default=False, null=True),
        ),
        migrations.AlterField(
            model_name="slurpitinitipaddress",
            name="ignore_status",
            field=models.BooleanField(default=False, null=True),
        ),
        migrations.AlterField(
            model_name="slurpitinitipaddress",
            name="ignore_tenant",
            field=models.BooleanField(default=False, null=True),
        ),
        migrations.AlterField(
            model_name="slurpitinitipaddress",
            name="ignore_vrf",
            field=models.BooleanField(default=False, null=True),
        ),
        migrations.AlterField(
            model_name="slurpitinterface",
            name="ignore_duplex",
            field=models.BooleanField(default=False, null=True),
        ),
        migrations.AlterField(
            model_name="slurpitinterface",
            name="ignore_module",
            field=models.BooleanField(default=False, null=True),
        ),
        migrations.AlterField(
            model_name="slurpitinterface",
            name="ignore_speed",
            field=models.BooleanField(default=False, null=True),
        ),
        migrations.AlterField(
            model_name="slurpitinterface",
            name="ignore_type",
            field=models.BooleanField(default=False, null=True),
        ),
        migrations.AlterField(
            model_name="slurpitprefix",
            name="ignore_description",
            field=models.BooleanField(default=False, null=True),
        ),
        migrations.AlterField(
            model_name="slurpitprefix",
            name="ignore_role",
            field=models.BooleanField(default=False, null=True),
        ),
        migrations.AlterField(
            model_name="slurpitprefix",
            name="ignore_site",
            field=models.BooleanField(default=False, null=True),
        ),
        migrations.AlterField(
            model_name="slurpitprefix",
            name="ignore_status",
            field=models.BooleanField(default=False, null=True),
        ),
        migrations.AlterField(
            model_name="slurpitprefix",
            name="ignore_tenant",
            field=models.BooleanField(default=False, null=True),
        ),
        migrations.AlterField(
            model_name="slurpitprefix",
            name="ignore_vlan",
            field=models.BooleanField(default=False, null=True),
        ),
        migrations.AlterField(
            model_name="slurpitprefix",
            name="ignore_vrf",
            field=models.BooleanField(default=False, null=True),
        ),
        migrations.AlterField(
            model_name="slurpitvlan",
            name="ignore_description",
            field=models.BooleanField(default=False, null=True),
        ),
        migrations.AlterField(
            model_name="slurpitvlan",
            name="ignore_group",
            field=models.BooleanField(default=False, null=True),
        ),
        migrations.AlterField(
            model_name="slurpitvlan",
            name="ignore_role",
            field=models.BooleanField(default=False, null=True),
        ),
        migrations.AlterField(
            model_name="slurpitvlan",
            name="ignore_site",
            field=models.BooleanField(default=False, null=True),
        ),
        migrations.AlterField(
            model_name="slurpitvlan",
            name="ignore_status",
            field=models.BooleanField(default=False, null=True),
        ),
        migrations.AlterField(
            model_name="slurpitvlan",
            name="ignore_tenant",
            field=models.BooleanField(default=False, null=True),
        ),
        migrations.AlterField(
            model_name="slurpitvlan",
            name="ignore_vid",
            field=models.BooleanField(default=False, null=True),
        ),
    ]
