# Generated by Django 5.0.9 on 2024-10-10 09:09

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        (
            "slurpit_netbox",
            "0020_alter_slurpitinitipaddress_ignore_description_and_more",
        ),
    ]

    operations = [
        migrations.AddField(
            model_name="slurpitimporteddevice",
            name="site",
            field=models.CharField(max_length=255, null=True),
        ),
        migrations.AddField(
            model_name="slurpitstageddevice",
            name="site",
            field=models.CharField(max_length=255, null=True),
        ),
    ]
